@@ -9,7 +9,6 @@ from chromaformatter import ChromaFormatter
 from dataclasses_json import dataclass_json
 
 from snacks.rabbit import RabbitApp
-from snacks.rabbit_config import RabbitConfig
 
 log = logging.getLogger('snacks')
 log.setLevel(logging.INFO)
@@ -25,7 +24,7 @@ log.addHandler(stream_handler)
 log.setLevel(logging.DEBUG)
 
 # Initial setup of configuration and Rabbit class.
-config = RabbitConfig(
+rabbit = RabbitApp(
     host='localhost',
     port=5672,
     default_exchange='snacks',
@@ -33,7 +32,6 @@ config = RabbitConfig(
     username=os.environ.get('AMQP_USERNAME') or 'guest',
     password=os.environ.get('AMQP_PASSWORD') or 'guest'
 )
-rabbit = RabbitApp(config)
 # Setup queues to use.
 str_queue = 'snack_str'
 bytes_queue = 'snack_bytes'
